// Copyright 2000-2005 the Contributors, as shown in the revision logs.
// Licensed under the Apache Public Source License 2.0 ("the License").
// You may not use this file except in compliance with the License.

package org.ibex.js;

/** this class contains a <tt>public static final int</tt> for each valid token */
interface Tokens {

    // Token Constants //////////////////////////////////////////////////////////

    // arithmetic operations; also valid as bytecodes
    public static final int BITOR         = 0;   // |
    public static final int ASSIGN_BITOR  = 1;   // |=
    public static final int BITXOR        = 2;   // ^
    public static final int ASSIGN_BITXOR = 3;   // ^=
    public static final int BITAND        = 4;   // &
    public static final int ASSIGN_BITAND = 5;   // &=
    public static final int LSH           = 6;   // <<
    public static final int ASSIGN_LSH    = 7;   // <<=
    public static final int RSH           = 8;   // >>
    public static final int ASSIGN_RSH    = 9;   // >>=
    public static final int URSH          = 10;  // >>>
    public static final int ASSIGN_URSH   = 11;  // >>>=
    public static final int ADD           = 12;  // +
    public static final int ASSIGN_ADD    = 13;  // +=
    public static final int SUB           = 14;  // -
    public static final int ASSIGN_SUB    = 15;  // -=
    public static final int MUL           = 16;  // *
    public static final int ASSIGN_MUL    = 17;  // *=
    public static final int DIV           = 18;  // /
    public static final int ASSIGN_DIV    = 19;  // /=
    public static final int MOD           = 20;  // %
    public static final int ASSIGN_MOD    = 21;  // %=
    public static final int BITNOT        = 22;  // ~
    public static final int ASSIGN_BITNOT = 23;  // ~=

    // logical operations; also valid as bytecodes
    public static final int OR            = 24;  // ||
    public static final int AND           = 25;  // &&
    public static final int BANG          = 26;  // !

    // equality operations; also valid as bytecodes
    public static final int EQ            = 27;  // ==
    public static final int NE            = 28;  // !=
    public static final int LT            = 29;  // <
    public static final int LE            = 30;  // <=
    public static final int GT            = 31;  // >
    public static final int GE            = 32;  // >=
    public static final int SHEQ          = 33;  // ===
    public static final int SHNE          = 34;  // !==

    // other permissible bytecode tokens
    public static final int RETURN        = 35;  // return
    public static final int TYPEOF        = 36;  // typeof
    public static final int BREAK         = 37;  // break keyword
    public static final int CONTINUE      = 38;  // continue keyword
    public static final int TRY           = 39;  // try
    public static final int THROW         = 40;  // throw
    public static final int ASSERT        = 41;  // assert keyword

    public static final int NAME          = 42;  // *** identifiers ***
    public static final int NUMBER        = 43;  // *** numeric literals ***
    public static final int STRING        = 44;  // *** string literals ***
    public static final int NULL          = 45;  // null
    public static final int THIS          = 46;  // this
    public static final int FALSE         = 47;  // false
    public static final int TRUE          = 48;  // true
    public static final int IN            = 49;  // in

    public static final int SEMI          = 50;  // ;
    public static final int LB            = 51;  // [
    public static final int RB            = 52;  // ]
    public static final int LC            = 53;  // {
    public static final int RC            = 54;  // }
    public static final int LP            = 55;  // (
    public static final int RP            = 56;  // )
    public static final int COMMA         = 57;  // ,
    public static final int ASSIGN        = 58;  // =
    public static final int HOOK          = 59;  // ?
    public static final int COLON         = 60;  // :
    public static final int INC           = 61;  // ++
    public static final int DEC           = 62;  // --
    public static final int DOT           = 63;  // .
    public static final int FUNCTION      = 64;  // function
    public static final int IF            = 65;  // if keyword
    public static final int ELSE          = 66;  // else keyword
    public static final int SWITCH        = 67;  // switch keyword
    public static final int CASE          = 68;  // case keyword
    public static final int DEFAULT       = 69;  // default keyword
    public static final int WHILE         = 70;  // while keyword
    public static final int DO            = 71;  // do keyword
    public static final int FOR           = 72;  // for keyword
    public static final int VAR           = 73;  // var keyword
    public static final int WITH          = 74;  // with keyword
    public static final int CATCH         = 75;  // catch keyword
    public static final int FINALLY       = 76;  // finally keyword
    public static final int RESERVED      = 77;  // reserved keyword
    public static final int GRAMMAR       = 78;  // the grammar-definition operator (::=)
    public static final int ADD_TRAP      = 79;  // the add-trap operator (++=)
    public static final int DEL_TRAP      = 80;  // the del-trap operator (--=)
    public static final int CASCADE       = 81;  // cascade expression - arg==true for write cascade
 
    public static final int MAX_TOKEN = DEL_TRAP;

    public final static String[] codeToString = new String[] {
        "BITOR", "ASSIGN_BITOR", "BITXOR", "ASSIGN_BITXOR", "BITAND",
        "ASSIGN_BITAND", "LSH", "ASSIGN_LSH", "RSH", "ASSIGN_RSH",
        "URSH", "ASSIGN_URSH", "ADD", "ASSIGN_ADD", "SUB",
        "ASSIGN_SUB", "MUL", "ASSIGN_MUL", "DIV", "ASSIGN_DIV", "MOD",
        "ASSIGN_MOD", "BITNOT", "ASSIGN_BITNOT", "OR", "AND", "BANG",
        "EQ", "NE", "LT", "LE", "GT", "GE", "SHEQ", "SHNE", "RETURN",
        "TYPEOF", "BREAK", "CONTINUE", "TRY", "THROW", "ASSERT", "NAME",
        "NUMBER", "STRING", "NULL", "THIS", "FALSE", "TRUE", "IN",
        "SEMI", "LB", "RB", "LC", "RC", "LP", "RP", "COMMA", "ASSIGN",
        "HOOK", "COLON", "INC", "DEC", "DOT", "FUNCTION", "IF",
        "ELSE", "SWITCH", "CASE", "DEFAULT", "WHILE", "DO", "FOR",
        "VAR", "WITH", "CATCH", "FINALLY", "RESERVED", "GRAMMAR",
        "ADD_TRAP", "DEL_TRAP", "CASCADE"
    };

}


